==> ukui-menu-extensions_4.10.1.5.orig.tar.xz: ukui-menu-extensions-4.10.1.5/ernie-bot/translations/ernie-bot_ug_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ug_CN">
<context>
    <name>ErnieBot</name>
    <message>
        <source>AI Assistant</source>
        <translation>ياردەمچىسى AI</translation>
    </message>
</context>
<context>
    <name>MessageBar</name>
    <message>
        <source>Copy</source>
        <translation>كۆچۈرۈش</translation>
    </message>
</context>
<context>
    <name>MessageInput</name>
    <message>
        <source>You can ask me any questions~</source>
        <translation>مەندىن ھەرقانداق سوئال سورىسىڭىز بولىدۇ~</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>You can try asking me:</source>
        <translation>:مەندىن سورىسىڭىز بولىدۇ</translation>
    </message>
    <message>
        <source>How are you today!</source>
        <translation>!بۈگۈن كەيپىياتىڭىز قانداقراق</translation>
    </message>
    <message>
        <source>Good morning!</source>
        <translation>!خەيرىلىك سەھەر</translation>
    </message>
    <message>
        <source>Good afternoon!</source>
        <translation>!چۈشتىن كېيىنلىكىڭىز خەيرلىك بولسۇن</translation>
    </message>
    <message>
        <source>Hi, %1</source>
        <translation>ھەي، %1</translation>
    </message>
    <message>
        <source>What can AI do?</source>
        <translation>نېمە قىلالايدۇ؟ AI</translation>
    </message>
    <message>
        <source>Give it a try</source>
        <translation>سىناپ بىقىڭ</translation>
    </message>
    <message>
        <source>Help me write a product requirements document.</source>
        <translation>ماڭا بىر پارچە مەھسۇلات ئېھتىياج ھۆججىتى يېزىپ بېرىڭ.</translation>
    </message>
    <message>
        <source>What gift to give on Mother&apos;s Day is more intentional?</source>
        <translation>ئانىلار بايرىمىدا قانداق سوۋغات بەرسە تېخىمۇ ياخشى؟</translation>
    </message>
    <message>
        <source>Session: %1</source>
        <translation>سۆزلىشىش : %1</translation>
    </message>
    <message>
        <source>The current network is not good, please check the network.

Error: </source>
        <translation>ھازىر تور ياخشى ئەمەس ، تور ئۇلىنىشىنى تەكشۈرۈڭ.

Error: </translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>قايتا سىناش</translation>
    </message>
</context>
<context>
    <name>SessionLoginPage</name>
    <message>
        <source>Ai Assistant</source>
        <translation>ياردەمچىسى Ai</translation>
    </message>
    <message>
        <source>AI assistant is a large language model of artificial intelligence, which has the ability of deep semantic understanding and generation across modes and languages. It has five abilities: literary creation, commercial copy creation, mathematical logic calculation, Chinese understanding, multimodal generation, and so on. It has a broader imagination space in many fields, such as search question and answer, content creation, intelligent office and so on.</source>
        <translation>AI ياردەمچىسى سۈنئىي ئەقلىي ئىقتىدارلىق تىل قېلىپى بولۇپ، مودال ھالقىغان، تىل ھالقىغان چوڭقۇر سېمانتىكىلىق چۈشىنىش ۋە ھاسىل قىلىش ئىقتىدارىغا ئىگە، ئەدەبىيات ئىجادىيىتى، سودا يېزىقچىلىق ئىجادىيىتى، ماتېماتىكىلىق لوگىكىلىق ھېسابلاش، دۆلەت تىلىدا چۈشىنىش، كۆپ مودال ھاسىل قىلىشتىن ئىبارەت بەش چوڭ ئىقتىدارى بار، سوئال-جاۋاپ ئىزدەش، مەزمۇن ئىجادىيىتى ھاسىل قىلىش، ئەقلىي ئىقتىدارلىق ئىش بېجىرىش قاتارلىق نۇرغۇنلىغان ساھەلەردە تېخىمۇ كەڭ تەسەۋۋۇر بوشلۇقىغا ئىگە.</translation>
    </message>
    <message>
        <source>Input API Key</source>
        <translation>نى كىرگۈزۈڭ APIKey</translation>
    </message>
    <message>
        <source>Input Secret Key</source>
        <translation>نى كىرگۈزۈڭ Secret Key</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>جەزىملەشتۈرۈش</translation>
    </message>
</context>
<context>
    <name>SessionPage</name>
    <message>
        <source>Select Session</source>
        <translation>سۆزلىشىشنى تاللاش</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>يىڭىدىن سۆزلىشىش</translation>
    </message>
    <message>
        <source>Clear Session</source>
        <translation>سۆزلىشىشنى بىكار قىلىش</translation>
    </message>
    <message>
        <source>Exit ID</source>
        <translation>دىن چېكىنىش ID</translation>
    </message>
</context>
</TS>

==> ukui-menu-extensions_4.20.0.1.orig.tar.xz: ukui-menu-extensions-4.20.0.1/ernie-bot/translations/ernie-bot_ug_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ug_CN">
<context>
    <name>ErnieBot</name>
    <message>
        <source>AI Assistant</source>
        <translation>ياردەمچىسى AI</translation>
    </message>
</context>
<context>
    <name>MessageBar</name>
    <message>
        <source>Copy</source>
        <translation>كۆچۈرۈش</translation>
    </message>
</context>
<context>
    <name>MessageInput</name>
    <message>
        <source>You can ask me any questions~</source>
        <translation>مەندىن ھەرقانداق سوئال سورىسىڭىز بولىدۇ~</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>You can try asking me:</source>
        <translation>:مەندىن سورىسىڭىز بولىدۇ</translation>
    </message>
    <message>
        <source>How are you today!</source>
        <translation>!بۈگۈن كەيپىياتىڭىز قانداقراق</translation>
    </message>
    <message>
        <source>Good morning!</source>
        <translation>!خەيرلىك سەھەر</translation>
    </message>
    <message>
        <source>Good afternoon!</source>
        <translation>!چۈشتىن كېيىنلىكىڭىز خەيرلىك بولسۇن</translation>
    </message>
    <message>
        <source>Hi, %1</source>
        <translation>ھەي، %1</translation>
    </message>
    <message>
        <source>What can AI do?</source>
        <translation>نېمە قىلالايدۇ؟ AI</translation>
    </message>
    <message>
        <source>Give it a try</source>
        <translation>سىناپ بېقىڭ</translation>
    </message>
    <message>
        <source>Help me write a product requirements document.</source>
        <translation>ماڭا بىر پارچە مەھسۇلات ئېھتىياج ھۆججىتى يېزىپ بېرىڭ.</translation>
    </message>
    <message>
        <source>What gift to give on Mother&apos;s Day is more intentional?</source>
        <translation>ئانىلار بايرىمىدا قانداق سوۋغات بەرسە تېخىمۇ ياخشى؟</translation>
    </message>
    <message>
        <source>Session: %1</source>
        <translation>سۆزلىشىش : %1</translation>
    </message>
    <message>
        <source>The current network is not good, please check the network.

Error: </source>
        <translation>ھازىر تور ياخشى ئەمەس ، تور ئۇلىنىشىنى تەكشۈرۈڭ.

Error: </translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>قايتا سىناش</translation>
    </message>
</context>
<context>
    <name>SessionLoginPage</name>
    <message>
        <source>Ai Assistant</source>
        <translation>ياردەمچىسى Ai</translation>
    </message>
    <message>
        <source>AI assistant is a large language model of artificial intelligence, which has the ability of deep semantic understanding and generation across modes and languages. It has five abilities: literary creation, commercial copy creation, mathematical logic calculation, Chinese understanding, multimodal generation, and so on. It has a broader imagination space in many fields, such as search question and answer, content creation, intelligent office and so on.</source>
        <translation>AI ياردەمچىسى سۈنئىي ئەقلىي ئىقتىدارلىق تىل قېلىپى بولۇپ، مودال ھالقىغان، تىل ھالقىغان چوڭقۇر سېمانتىكىلىق چۈشىنىش ۋە ھاسىل قىلىش ئىقتىدارىغا ئىگە، ئەدەبىيات ئىجادىيىتى، سودا يېزىقچىلىق ئىجادىيىتى، ماتېماتىكىلىق لوگىكىلىق ھېسابلاش، دۆلەت تىلىدا چۈشىنىش، كۆپ مودال ھاسىل قىلىشتىن ئىبارەت بەش چوڭ ئىقتىدارى بار، سوئال-جاۋاپ ئىزدەش، مەزمۇن ئىجادىيىتى ھاسىل قىلىش، ئەقلىي ئىقتىدارلىق ئىش بېجىرىش قاتارلىق نۇرغۇنلىغان ساھەلەردە تېخىمۇ كەڭ تەسەۋۋۇر بوشلۇقىغا ئىگە.</translation>
    </message>
    <message>
        <source>Input API Key</source>
        <translation>نى كىرگۈزۈڭ APIKey</translation>
    </message>
    <message>
        <source>Input Secret Key</source>
        <translation>نى كىرگۈزۈڭ Secret Key</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>جەزملەشتۈرۈش</translation>
    </message>
</context>
<context>
    <name>SessionPage</name>
    <message>
        <source>Select Session</source>
        <translation>سۆزلىشىشنى تاللاش</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>يېڭىدىن سۆزلىشىش</translation>
    </message>
    <message>
        <source>Clear Session</source>
        <translation>سۆزلىشىشنى بىكار قىلىش</translation>
    </message>
    <message>
        <source>Exit ID</source>
        <translation>دىن چېكىنىش ID</translation>
    </message>
</context>
</TS>
